# PHOXENE Modbus driver

![Build Status](https://img.shields.io/pypi/v/phox_modbus.svg)
![python](https://img.shields.io/pypi/pyversions/phox_modbus.svg)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Documentation Status](https://readthedocs.org/projects/phox-modbus/badge/?version=main)](https://phox-modbus.readthedocs.io/)

![Phoxene Logo](https://www.phoxene.com/wp-content/uploads/2018/09/flash-strobe-manufacturer-phoxene.png)

This module is a Python Modbus RTU on serial port driver

# Usage
This driver has been developped as Modbus layer for PHOXENE's devices that
implements a serial Modbus communication.

It is mainly used by Phoxene's applications or devices' drivers 

# Documentation
https://phox-modbus.readthedocs.io/en/main/

# Installation
```shell
pip install -i https://pypi.org/simple/ phox_modbus
```

# Dependencies
* pySerial

# Compatibility
Tested on Windows 10 and Debian 12.2

![Windows Logo](https://img.shields.io/badge/Windows-0078D6?style=for-the-badge&logo=windows&logoColor=white)
![Debian Logo](https://img.shields.io/badge/Debian-A81D33?style=for-the-badge&logo=debian&logoColor=white)

# Licence
MIT License Copyright (c) 2023 PHOXENE

See LICENSE file

# Authors
written by Aurélien PLANTIN <a.plantin@phoxene.com>